StatusCode

Enum StatusCode 

pub enum StatusCode {
    Ok = 0,
    Eof = 1,
    NoSuchFile = 2,
    PermissionDenied = 3,
    Failure = 4,
    BadMessage = 5,
    NoConnection = 6,
    ConnectionLost = 7,
    OpUnsupported = 8,
}
Error Codes for SSH_FXP_STATUS

Variants



Ok = 0

Indicates successful completion of the operation.



Eof = 1

Indicates end-of-file condition; for SSH_FX_READ it means that no more data is available in the file, and for SSH_FX_READDIR it indicates that no more files are contained in the directory.



NoSuchFile = 2

A reference is made to a file which should exist but doesn’t.



PermissionDenied = 3

Authenticated user does not have sufficient permissions to perform the operation.



Failure = 4

A generic catch-all error message; it should be returned if an error occurs for which there is no more specific error code defined.



BadMessage = 5

May be returned if a badly formatted packet or protocol incompatibility is detected.



NoConnection = 6

A pseudo-error which indicates that the client has no connection to the server (it can only be generated locally by the client, and MUST NOT be returned by servers).



ConnectionLost = 7

A pseudo-error which indicates that the connection to the server has been lost (it can only be generated locally by the client, and MUST NOT be returned by servers).



OpUnsupported = 8

Indicates that an attempt was made to perform an operation which is not supported for the server (it may be generated locally by the client if e.g. the version number exchange indicates that a required feature is not supported by the server, or it may be returned by the server if the server does not implement an operation).