FileAttributes

Struct FileAttributes 

pub struct FileAttributes {
    pub size: Option<u64>,
    pub uid: Option<u32>,
    pub user: Option<String>,
    pub gid: Option<u32>,
    pub group: Option<String>,
    pub permissions: Option<u32>,
    pub atime: Option<u32>,
    pub mtime: Option<u32>,
}
Used in the implementation of other packets. Implements most Metadata methods

The fields user and group are string names of users and groups for clients that can be displayed in longname. Can be omitted.

The flags field is omitted because it is set by itself depending on the fields

Fields

size: Option<u64>uid: Option<u32>user: Option<String>gid: Option<u32>group: Option<String>permissions: Option<u32>atime: Option<u32>mtime: Option<u32>

Implementations

Source

impl FileAttributes

pub fn is_dir(&self) -> bool

Returns true if is a dir

pub fn set_dir(&mut self, is_dir: bool)

Set flag if is a dir or not

pub fn is_regular(&self) -> bool

Returns true if is a regular

pub fn set_regular(&mut self, is_regular: bool)

Set flag if is a regular or not

Returns true if is a symlink

Set flag if is a symlink or not

pub fn is_character(&self) -> bool

Returns true if is a character

pub fn set_character(&mut self, is_character: bool)

Set flag if is a character or not

pub fn is_block(&self) -> bool

Returns true if is a block

pub fn set_block(&mut self, is_block: bool)

Set flag if is a block or not

pub fn is_fifo(&self) -> bool

Returns true if is a fifo

pub fn set_fifo(&mut self, is_fifo: bool)

Set flag if is a fifo or not

pub fn set_type(&mut self, mode: FileMode)

Set mode flag

pub fn remove_type(&mut self, mode: FileMode)

Remove mode flag

pub fn file_type(&self) -> FileType

Returns the file type

pub fn is_empty(&self) -> bool

Returns true if is empty

pub fn len(&self) -> u64

Returns the size of the file

pub fn permissions(&self) -> FilePermissions

Returns the permissions of the file this metadata is for.

pub fn accessed(&self) -> Result<SystemTime>

Returns the last access time

pub fn modified(&self) -> Result<SystemTime>

Returns the last modification time

pub fn empty() -> Self

Creates a structure with omitted attributes